@@ -3,16 +3,17 @@ import shutil
 import json
 import urllib3
 import platform
+import logging
 import subprocess
 import functools
 import traceback
 import inspect
-from log import log
 from typing import List, Optional, Set, Union, Any, Callable
 from git import Repo,GitCommandError
 
 urllib3.disable_warnings(urllib3.exceptions.InsecureRequestWarning)
 
+log=logging.getLogger(__name__)
 
 def enter_and_leave_function(func: Callable) -> Callable:
     """
